%%%% Compute necessary objects for figures 
A = oo_.dr.ghx;
B = oo_.dr.ghu; 

periods = 60; 

y = zeros(size(A,1),periods); 
u = [zeros(2,1);sigma_v;zeros(3,1)];  %%% shock to v 

y(oo_.dr.order_var,1) = B*u; 

for i =2:periods 
    
y(oo_.dr.order_var,i) = A*y(oo_.dr.state_var,i-1); 
end



ihat = y(17,:); 
istar_hat = y(18,:); 

idiff = ihat - istar_hat; 
lambda_hat = y(7,:);

%%% Theoretical Regression Coefficients

%%% Solving for the variance of the states as a Lyapunov eq
As = A(oo_.dr.inv_order_var(oo_.dr.state_var),:); 
s_ind = find(oo_.dr.state_var ==5);
As2 = As([1:s_ind-1,s_ind+1:length(oo_.dr.state_var)],[1:s_ind-1,s_ind+1:length(oo_.dr.state_var)]);
Bs = B(oo_.dr.inv_order_var(oo_.dr.state_var),:); 
Bs2 = Bs([1:s_ind-1,s_ind+1:length(oo_.dr.state_var)],:); 
Sigma_a =[ sigma_a^2,sigma_aastar^2;
         sigma_aastar^2, sigma_astar^2];
Sigma_v = [ sigma_v^2,sigma_vvstar^2;
         sigma_vvstar^2, sigma_vstar^2];
Sigma_vtau = [ sigma_vtau^2,sigma_vvtaustar^2;
         sigma_vvtaustar^2, sigma_vtaustar^2];

         
Sigma_u = blkdiag(Sigma_a,Sigma_v,Sigma_vtau); 

var_s = dlyap(As2,Bs2*Sigma_u*Bs2');

%%% Solving for the variance of the states by iterating 
var_s2 = zeros(size(As2)); 
for i =1:5000
    var_s2 = var_s2 + As2^(i-1)*Bs2*Sigma_u*(As2^(i-1)*Bs2)';
end

temp = NaN(size(As)); 
temp([1:s_ind-1,s_ind+1:length(oo_.dr.state_var)],[1:s_ind-1,s_ind+1:length(oo_.dr.state_var)]) = var_s; 

A2 = A(:,[1:s_ind-1,s_ind+1:length(oo_.dr.state_var)]); 
var_y = A2*var_s*A2' + B*Sigma_u*B'; 
var_y = var_y(oo_.dr.inv_order_var,:);
var_y = var_y(:,oo_.dr.inv_order_var); 



ks = zeros(size(As,1),size(A,1)); %%% Selection matrix for the state variables
for i=1:length(As)
    ks(i,oo_.dr.state_var(i)) = 1; 
end

ky = zeros(size(A,1));  %%% Selection matrix for dectlaration order 

for i=1:length(A)
    ky(i,oo_.dr.inv_order_var(i)) = 1; 
end

ei = [zeros(1,16),1,-1,zeros(1,length(A)-18)];
eds = [zeros(1,length(A)-1),1];
%eds = [zeros(1,75),1,zeros(1,length(A)-76)];

e_lambdahat = [zeros(1,6),1,zeros(1,length(A)-7)]; 

e_psi3 =[zeros(1,8),1,zeros(1,length(A)-9)];
e_bhgy = [zeros(1,29),1,zeros(1,length(A)-30)]; 
e_diff_bhgy = [zeros(1,41),1,zeros(1,length(A)-42)]; 

edq = [zeros(1,length(A)-2),1,0]; 
%edq = [zeros(1,74),1,zeros(1,length(A)-75)]; 

e_rdiff = [zeros(1, length(A)-6),1,-1,0,0,0,0];
eq      = [zeros(1,13),1, zeros(1,length(A)-14)]; 
%e_rdiff = [zeros(1, 72),1,-1,zeros(1,length(A)-74)]; 

cov_li = eds*ky*A*ks*var_y*ei' - ei*var_y*ei';
cov_lambdahat_idiff = e_lambdahat*var_y*ei';
cov_psi3_bhgy = e_psi3*var_y*e_bhgy'; 

var_idiff = ei*var_y*ei';
var_sdiff = eds*var_y*eds'; 
var_psi3 = e_psi3*var_y*e_psi3';  
var_bhgy = e_bhgy*var_y*e_bhgy'; 
var_diff_bhgy = e_diff_bhgy*var_y*e_diff_bhgy'; 
var_rdiff = e_rdiff*var_y*e_rdiff'; 

reg_periods = periods; 
beta_l = NaN(reg_periods,1); 
beta_sj = NaN(reg_periods,1); 
beta_i = NaN(reg_periods,1); 
beta_lrdiff = NaN(reg_periods,1); 


for i = 1:reg_periods 
    cov_li = eds*((ky*A*ks)^i)*var_y*ei' - ei*((ky*A*ks)^(i-1))*var_y*ei';
    beta_l(i) = cov_li/var_idiff; 
    
    cov_sj = 0; 
    for j = 1:i
        cov_sj = cov_sj + eds*((ky*A*ks)^(j))*var_y*ei';
    end
    
    beta_sj(i) = cov_sj/var_idiff;
    
    cov_iidiff = ei*((ky*A*ks)^(i-1))*var_y*ei';
    beta_i(i) = cov_iidiff/var_idiff; 
    
    cov_lrdiff = edq*((ky*A*ks)^i)*var_y*e_rdiff' - e_rdiff*((ky*A*ks)^(i-1))*var_y*e_rdiff';
    beta_lrdiff(i) = cov_lrdiff/var_rdiff; 
    i;
end

cov_qrdiff = eq*var_y*e_rdiff';
bq = cov_qrdiff/var_rdiff; 


%% Impulse Response Functions

%%%%%% Monetary Shocks
bhg_irf_v = oo_.irfs.bh_g_eps_v; 
tau_irf_v = oo_.irfs.tau_eps_v; 
m_irf_v = oo_.irfs.m_eps_v; 
pi_irf_v = oo_.irfs.pi_eps_v; 
i_irf_v = oo_.irfs.i_eps_v; 
istar_irf_v = oo_.irfs.i_star_eps_v; 
psi3hat_irf_v = oo_.irfs.psi3_hat_eps_v; 
psi4hat_irf_v = oo_.irfs.psi4_hat_eps_v; 
lambda_hat_irf_v = oo_.irfs.lambda_hat_eps_v; 
lambda_irf_v     = oo_.irfs.lambda_eps_v; 
idiff_irf_v = oo_.irfs.idiff_eps_v; 
y_irf_v = oo_.irfs.yh_eps_v; 
c_irf_v = oo_.irfs.c_eps_v; 
yhtilde_irf = oo_.irfs.yh_tilde_eps_v; 
pi_ht_irf_v = oo_.irfs.pi_h_eps_v; 
yh_irf_v = oo_.irfs.yh_eps_v; 
bh_irf_v = oo_.irfs.bh_eps_v; 
bf_irf_v = oo_.irfs.bf_eps_v; 
bhm_irf_v = oo_.irfs.bh_m_eps_v; 
q_irf_v   = oo_.irfs.q_eps_v; 
phhat_irf_v = oo_.irfs.ph_hat_eps_v; 
cstar_irf_v = oo_.irfs.c_star_eps_v; 
pfhat_irf_v = oo_.irfs.pf_hat_eps_v; 
s_irf_v     = oo_.irfs.s_eps_v; 
r_irf_v     = oo_.irfs.r_eps_v; 
bhg_irf_v   = oo_.irfs.bh_g_eps_v; 
rdiff_irf_v = oo_.irfs.rdiff_eps_v; 

ex_irf_v = (1-eta)*phhat_irf_v + eta*q_irf_v + cstar_irf_v; 
im_irf_v = (1-eta)*pfhat_irf_v + c_irf_v; 

tb_irf_v = ex_irf_v - im_irf_v;

%%% Technology Shocks

bhg_irf_a = oo_.irfs.bh_g_eps_a; 
tau_irf_a = oo_.irfs.tau_eps_a; 
m_irf_a = oo_.irfs.m_eps_a; 
pi_irf_a = oo_.irfs.pi_eps_a; 
i_irf_a = oo_.irfs.i_eps_a; 
istar_irf_a = oo_.irfs.i_star_eps_a; 
psi3hat_irf_a = oo_.irfs.psi3_hat_eps_a; 
psi4hat_irf_a = oo_.irfs.psi4_hat_eps_a; 
lambda_hat_irf_a = oo_.irfs.lambda_hat_eps_a; 
lambda_irf_a     = oo_.irfs.lambda_eps_a; 
idiff_irf_a = oo_.irfs.idiff_eps_a; 
y_irf_a = oo_.irfs.yh_eps_a; 
c_irf_a = oo_.irfs.c_eps_a; 
yhtilde_irf_a = oo_.irfs.yh_tilde_eps_a; 
pi_ht_irf_a = oo_.irfs.pi_h_eps_a; 
yh_irf_a = oo_.irfs.yh_eps_a; 
bh_irf_a = oo_.irfs.bh_eps_a; 
bf_irf_a = oo_.irfs.bf_eps_a; 
bhm_irf_a = oo_.irfs.bh_m_eps_a; 
q_irf_a   = oo_.irfs.q_eps_a; 
phhat_irf_a = oo_.irfs.ph_hat_eps_a; 
cstar_irf_a = oo_.irfs.c_star_eps_a; 
pfhat_irf_a = oo_.irfs.pf_hat_eps_a; 
s_irf_a     = oo_.irfs.s_eps_a; 
r_irf_a     = oo_.irfs.r_eps_a; 
bhg_irf_a   = oo_.irfs.bh_g_eps_a; 
rdiff_irf_a = oo_.irfs.rdiff_eps_a; 

ex_irf_a = (1-eta)*phhat_irf_a + eta*q_irf_a + cstar_irf_a; 
im_irf_a = (1-eta)*pfhat_irf_a + c_irf_a; 

tb_irf_a = ex_irf_a - im_irf_a;


%% Figures 
load('emp_betas.mat'); 

%%%%% Figure 3 , panel a) 
%(Figure 6: shut down either monetary or TFP
% shocks in model_solution.mod)
%(Figure 8, panel a): change eta_b in model_solution.mod
%(Figure 9, panel a): run insteadm model_solution_incomplete_mkts.mod

figure 
hold on
plot(1:60,beta_l,1:60,bl3m_stata_fe76,'k--','LineWidth',2.5)
plot(zeros(length(beta_l),1),'k:')
hold off
xlabel('Horizon (Quarters)')
ylabel('\beta _{k}')
h = legend('\beta_k^{Model}','\beta_k^{Data}');
set(h, 'FontSize',12)

 
%%%%% Figure 3 , panel b)
figure 
hold on
plot(1:60,beta_sj,1:60,bsj3m,'k--','LineWidth',2.5) 
plot(zeros(length(beta_l),1),'k:')
hold off
xlabel('Horizon (Quarters)')
ylabel('\gamma _{k}')
h = legend('\gamma_k^{Model}','\gamma_k^{Data}', 'location', 'northwest');
set(h, 'FontSize',12)

%%%%% Figure 5 
%(panel b): turn on fiscal shocks in model_solution.mod, line 88)
%(Figure 8, panel b): change eta_b in model_solution.mod)
%(Figure 9, panel b): run insteadm model_solution_incomplete_mkts.mod

figure 
hold on
plot(1:60,beta_lrdiff,1:60,beta_r2,'k--','LineWidth',2.5)
plot(zeros(length(beta_l),1),'k--')
hold off
xlabel('Horizon (Quarters)')
ylabel('\beta _{k}')
h = legend('\beta_k^{real, Model}','\beta_k^{real, Data}');
set(h, 'FontSize',12); 

%%% Figure 7, Impulse Response Functions
line_width = 2; 
factor = 100; 
figure
subplot(5,2,1)
hold on
plot(1:periods, factor*y_irf_v, 1:periods, factor*y_irf_a,'--', 'LineWidth',line_width)
plot(zeros(length(i_irf_v),1),'k:')
xlim([0 periods])
hold off
legend('Monetary Shock', 'TFP shock','Location','SouthEast')
title('Output')
xlabel('Quarters')
ylabel('Percent')

subplot(5,2,2)
hold on 
plot(1:periods, factor*c_irf_v, 1:periods, factor*c_irf_a,'--','LineWidth',line_width)
plot(zeros(length(i_irf_v),1),'k:')
xlim([0 periods])
hold off
title('Consumption')
xlabel('Quarters')
ylabel('Percent')

subplot(5,2,3)
hold on
plot(1:periods,factor*tb_irf_v, 1:periods, factor*tb_irf_a,'--','LineWidth',line_width)
plot(zeros(length(i_irf_v),1),'k:')
xlim([0 periods])
hold off
title('Trade Balance')
xlabel('Quarters')
ylabel('Percent')

subplot(5,2,4)
hold on 
plot(1:periods,factor*s_irf_v, 1:periods, factor*s_irf_a,'--','LineWidth',line_width)
plot(zeros(length(i_irf_v),1),'k:')
xlim([0 periods])

hold off
title('Nominal Exchange Rate')
xlabel('Quarters')
ylabel('Percent')

subplot(5,2,5)
hold on 
plot(1:periods,factor*q_irf_v, 1:periods, factor*q_irf_a,'--','LineWidth',line_width)
plot(zeros(length(i_irf_v),1),'k:')
xlim([0 periods])

hold off
title('Real Exchange Rate')
xlabel('Quarters')
ylabel('Percent')

subplot(5,2,6)
hold on 
plot(1:periods,factor*idiff_irf_v, 1:periods, factor*i_irf_a,'--','LineWidth',line_width)
plot(zeros(length(i_irf_v),1),'k:')
xlim([0 periods])

hold off
title('Nominal Interest Rate')
xlabel('Quarters')
ylabel('Percent')

subplot(5,2,7)
hold on 
plot(1:periods,factor*rdiff_irf_v, 1:periods, factor*rdiff_irf_a,'--','LineWidth',line_width)
plot(zeros(length(i_irf_v),1),'k:')
xlim([0 periods])

hold off
title('Real Interest Rate')
xlabel('Quarters')
ylabel('Percent')

subplot(5,2,8)
hold on 
plot(1:periods,factor*bhg_irf_v, 1:periods, factor*bhg_irf_a,'--','LineWidth',line_width)
plot(zeros(length(i_irf_v),1),'k:')
xlim([0 periods])

hold off
title('Home Government Debt Supply')
xlabel('Quarters')
ylabel('Percent')

subplot(5,2,9)
hold on 
plot(1:periods,-factor*psi3hat_irf_v, 1:periods, -factor*psi3hat_irf_a,'--','LineWidth',line_width)
plot(zeros(length(i_irf_v),1),'k:')
xlim([0 periods])

hold off
title('Home Convenience Yield')
xlabel('Quarters')
ylabel('Percent')

subplot(5,2,10)
hold on 
plot(1:periods,factor*lambda_hat_irf_v, 1:periods, factor*lambda_hat_irf_a,'--','LineWidth',line_width)
plot(zeros(length(i_irf_v),1),'k:')
xlim([0 periods])
%ylim([-0.1,0.1])

hold off
title('Expected Excess Currency Return')
xlabel('Quarters')
ylabel('Percent')



