function [residual, g1, g2, g3] = anal_model_solution_dynamic(y, x, params, steady_state, it_)
%
% Status : Computes dynamic model for Dynare
%
% Inputs :
%   y         [#dynamic variables by 1] double    vector of endogenous variables in the order stored
%                                                 in M_.lead_lag_incidence; see the Manual
%   x         [nperiods by M_.exo_nbr] double     matrix of exogenous variables (in declaration order)
%                                                 for all simulation periods
%   steady_state  [M_.endo_nbr by 1] double       vector of steady state values
%   params    [M_.param_nbr by 1] double          vector of parameter values in declaration order
%   it_       scalar double                       time period for exogenous variables for which to evaluate the model
%
% Outputs:
%   residual  [M_.endo_nbr by 1] double    vector of residuals of the dynamic model equations in order of 
%                                          declaration of the equations.
%                                          Dynare may prepend auxiliary equations, see M_.aux_vars
%   g1        [M_.endo_nbr by #dynamic variables] double    Jacobian matrix of the dynamic model equations;
%                                                           rows: equations in order of declaration
%                                                           columns: variables in order stored in M_.lead_lag_incidence followed by the ones in M_.exo_names
%   g2        [M_.endo_nbr by (#dynamic variables)^2] double   Hessian matrix of the dynamic model equations;
%                                                              rows: equations in order of declaration
%                                                              columns: variables in order stored in M_.lead_lag_incidence followed by the ones in M_.exo_names
%   g3        [M_.endo_nbr by (#dynamic variables)^3] double   Third order derivative matrix of the dynamic model equations;
%                                                              rows: equations in order of declaration
%                                                              columns: variables in order stored in M_.lead_lag_incidence followed by the ones in M_.exo_names
%
%
% Warning : this file is generated automatically by Dynare
%           from model file (.mod)

%
% Model equations
%

residual = zeros(10, 1);
lhs =0;
rhs =y(8)-y(17)-(params(13)+params(14))*y(12)+params(14)*y(18);
residual(1)= lhs-rhs;
lhs =y(12)+params(21)/params(27)*y(13)+(1+params(26))*y(7);
rhs =(1+params(26))*(y(2)+y(1))+params(24)/params(27)*y(16);
residual(2)= lhs-rhs;
lhs =y(13);
rhs =params(28)*y(3)+y(2)*(1-params(28))*params(25)/params(21)*params(5)+y(14);
residual(3)= lhs-rhs;
lhs =y(8);
rhs =y(1)*params(3)+y(7)*(1-params(3))*params(4)+y(15);
residual(4)= lhs-rhs;
lhs =y(9);
rhs =y(17);
residual(5)= lhs-rhs;
lhs =y(11);
rhs =y(12)*(-params(13));
residual(6)= lhs-rhs;
lhs =y(10);
rhs =y(8)+y(11);
residual(7)= lhs-rhs;
lhs =y(14);
rhs =params(15)*y(4)+x(it_, 1);
residual(8)= lhs-rhs;
lhs =y(15);
rhs =params(16)*y(5)+x(it_, 2);
residual(9)= lhs-rhs;
lhs =y(16);
rhs =params(17)*y(6)+x(it_, 3);
residual(10)= lhs-rhs;
if nargout >= 2,
  g1 = zeros(10, 21);

  %
  % Jacobian matrix
  %

  g1(1,17)=1;
  g1(1,8)=(-1);
  g1(1,12)=params(13)+params(14);
  g1(1,18)=(-params(14));
  g1(2,7)=1+params(26);
  g1(2,1)=(-(1+params(26)));
  g1(2,2)=(-(1+params(26)));
  g1(2,12)=1;
  g1(2,13)=params(21)/params(27);
  g1(2,16)=(-(params(24)/params(27)));
  g1(3,2)=(-((1-params(28))*params(25)/params(21)*params(5)));
  g1(3,3)=(-params(28));
  g1(3,13)=1;
  g1(3,14)=(-1);
  g1(4,7)=(-((1-params(3))*params(4)));
  g1(4,1)=(-params(3));
  g1(4,8)=1;
  g1(4,15)=(-1);
  g1(5,17)=(-1);
  g1(5,9)=1;
  g1(6,11)=1;
  g1(6,12)=params(13);
  g1(7,8)=(-1);
  g1(7,10)=1;
  g1(7,11)=(-1);
  g1(8,4)=(-params(15));
  g1(8,14)=1;
  g1(8,19)=(-1);
  g1(9,5)=(-params(16));
  g1(9,15)=1;
  g1(9,20)=(-1);
  g1(10,6)=(-params(17));
  g1(10,16)=1;
  g1(10,21)=(-1);

if nargout >= 3,
  %
  % Hessian matrix
  %

  g2 = sparse([],[],[],10,441);
if nargout >= 4,
  %
  % Third order derivatives
  %

  g3 = sparse([],[],[],10,9261);
end
end
end
end
